/**
 * Class for generating the HTML and CSS for a diagram legend.
 */
export declare class DiagramLegend {
    private hasClassIcon;
    private hasAbstractClassIcon;
    private hasInterfaceIcon;
    private readonly hasPublicPropertyItem;
    private readonly hasProtectedPropertyItem;
    private readonly hasPrivatePropertyItem;
    private readonly hasPublicMethodItem;
    private readonly hasProtectedMethodItem;
    private readonly hasPrivateMethodItem;
    private readonly hasStaticMemberItem;
    private hasAbstractMemberItem;
    /**
     * Creates a new legend for a diagram.
     * @param hasClassItem Include the class item in the legend?
     * @param hasAbstractClassItem Include the abstract class item in the legend?
     * @param hasInterfaceItem Include the interface item in the legend?
     * @param hasPublicPropertyItem Include the public property item in the legend?
     * @param hasProtectedPropertyItem Include the protected property item in the legend?
     * @param hasPrivatePropertyItem Include the private property item in the legend?
     * @param hasPublicMethodItem Include the public method item in the legend?
     * @param hasProtectedMethodItem Include the protected method item in the legend?
     * @param hasPrivateMethodItem Include the private method item in the legend?
     * @param hasStaticMemberItem Include the static member item in the legend?
     * @param hasAbstractMemberItem Include the abstract member item in the legend?
     */
    constructor(hasClassItem?: boolean, hasAbstractClassItem?: boolean, hasInterfaceItem?: boolean, hasPublicPropertyItem?: boolean, hasProtectedPropertyItem?: boolean, hasPrivatePropertyItem?: boolean, hasPublicMethodItem?: boolean, hasProtectedMethodItem?: boolean, hasPrivateMethodItem?: boolean, hasStaticMemberItem?: boolean, hasAbstractMemberItem?: boolean);
    /**
     * Checks if the legend has nothing to display.
     * @returns True if the legend is empty, otherwise false.
     */
    get isEmpty(): boolean;
    /**
     * Tells the legend not to include icons for types.
     */
    hideTypeIcons(): void;
    /**
     * Tells the legend not to include the "italic" item for abstract members.
     */
    hideAbstractMemberItem(): void;
    /**
     * Creates the HTML for the diagram legend.
     * @param memberVisbilityStyle The style of the visibility of members in the diagram.
     * @returns The HTML for the diagram legend.
     */
    getHtml(memberVisbilityStyle: "text" | "icon"): string;
    /**
     * Returns the CSS that is required to format the HTML of the diagram legend.
     * @returns The CSS for the HTML of the diagram legend.
     */
    static getCss(): string;
}
/**
 * Creates a legend for the given PlantUML code.
 * @param plantUml The PlantUML lines of code for which the legend is generated.
 * @returns The legend for the PlantUML code.
 */
export declare function createDiagramLegendForPlantUml(plantUml: readonly string[]): DiagramLegend;
