/**
 * Creates a URL to a local image file.
 * @param pageFilePath Path of the page that is referencing the image.
 * @param imageFilePath Path to the local image file.
 * @returns The URL to the local image file.
 */
export declare function createLocalImageFileUrl(pageFilePath: string, imageFilePath: string): string;
/**
 * Creates a URL for an embedded image.
 * @param imageData The data of the image.
 * @param imageFormat The format of the image data.
 * @returns The URL for the embedded image.
 */
export declare function createEmbeddedImageUrl(imageData: Readonly<Buffer>, imageFormat: string): string;
/**
 * Creates a remote server URL that generates an image.
 * @param baseUrl The base URL for the image URL.
 * @param plantUmlCode The PlantUML code for the image.
 * @param imageFormat The format for the image.
 * @returns The remote server URL for the image.
 */
export declare function createRemoteImageUrl(baseUrl: string, plantUmlCode: string, imageFormat: string): string;
