/**
 * Class for generating diagrams from PlantUML code.
 * This class can spawn multiple PlantUML processes and evenly schedules the work between them.
 */
export declare class PlantUmlDiagramGenerator {
    /** Number of PlantUML processes used to schedule the diagram generation. */
    private readonly processCount;
    /** The format for the generated diagrams. */
    private readonly outputFormat;
    /** The object which encapsulates the PlantUML processes. */
    private readonly plantUmlProcesses;
    /** Index of the process that should generate the next diagram. */
    private nextProcessToGetWorkIndex;
    /**
     * Creates a new PlantUML generator object.
     * @param processCount Number of PlantUML processes used to schedule the diagram generation.
     * @param format The format for the generated diagrams.
     */
    constructor(processCount: number, format: "png" | "svg");
    /**
     * Writes the PlantUML code to a PlantUML process that generates the diagram.
     * @param plantUml The PlantUML code for the diagram.
     * @returns A promise that the diagram has been generated.
     */
    generate(plantUml: string): Promise<Readonly<Buffer>>;
    /**
     * Notifies the PlantUML diagram generator processes that there is no more job to do.
     */
    shutdown(): void;
    /**
     * Returns an object which encapsulates a PlantUML process that should generate the next diagram.
     * @returns An object for the process that should generate the next diagram.
     */
    private getNextProcess;
    /**
     * If necessary, spawns a new PlantUML process and stores it in the internal process array.
     */
    private maybeSpawnNewProcess;
    /**
     * Sets the internal index for the process that should receive the next job.
     */
    private setNextProcessForWork;
}
