import { type PageSections } from "./page_section.js";
/**
 * Helper class for finding sections on a TypeDoc page.
 */
export declare class PageSectionFinder {
    /** Map for caching regular expressions to find a section on a page. */
    private static readonly pageSectionLookUpCache;
    /**
     * Checks if there is a given section in the content.
     * @param content The content in which to look for the section.
     * @param section The section that is looked for.
     * @returns True, if the section is found in the content, otherwise false.
     */
    static hasSection(content: string, section: PageSections): boolean;
    /**
     * Returns the position of the section within the content.
     * @param content The content in which to look for the section.
     * @param section The section whos location is wanted.
     * @returns An object with the start and end index of the section.
     *          If the section cannot be found in the content both startIndex and endIndex equal 0.
     */
    static getSectionLocation(content: string, section: PageSections): {
        startIndex: number;
        endIndex: number;
    };
    /**
     * Returns a regular expression that can be used to match a section.
     * @param section The section to match.
     * @returns The regular expression to match the section.
     */
    private static getLookUpRegexpForSection;
    /**
     * Creates a regular expression that can be used to match a section with a given name.
     * @param sectionName The name of the section.
     * @returns The regular expression to match the section.
     */
    private static createLookUpRegexpForSection;
}
