import { type DeclarationReflection } from "typedoc";
/** Type for a reflection compare function for sorting reflections. */
export type TypeDocMemberCompareFunction = (a: Readonly<DeclarationReflection>, b: Readonly<DeclarationReflection>) => number;
/**
 * Compare function for sorting reflections by their name alphabetically.
 * @param a First reflection.
 * @param b Second reflection.
 * @returns -1 if (a < b), 0 if (a === b) or 1 if (a > b).
 */
export declare const nameAbc: TypeDocMemberCompareFunction;
/**
 * Compare function for sorting reflections by their visibility (public to private).
 * @param a First reflection.
 * @param b Second reflection.
 * @returns -1 if (a < b), 0 if (a === b) or 1 if (a > b).
 */
export declare const publicToPrivate: TypeDocMemberCompareFunction;
/**
 * Compare function for sorting reflections by their visibility (private to public).
 * @param a First reflection.
 * @param b Second reflection.
 * @returns -1 if (a < b), 0 if (a === b) or 1 if (a > b).
 */
export declare const privateToPublic: TypeDocMemberCompareFunction;
